@@ -1,6 +1,8 @@
 ordcont<-function (marginal, Sigma, support = list(), Spearman = FALSE, 
     epsilon = 1e-06, maxit = 100) 
 {
+        if (!all(unlist(lapply(marginal, function(x) (sort(x)==x & min(x)>0 & max(x)<1))))) stop("Error in assigning marginal distributions!")
+    if(!isSymmetric(Sigma) | min(eigen(Sigma)$values)<0 | !all(diag(Sigma)==1)) stop("Correlation matrix not valid!")
     len <- length(support)
     k <- length(marginal)
     niter<-matrix(0,k,k)
@@ -65,13 +67,14 @@ ordcont<-function (marginal, Sigma, support = list(), Spearman = FALSE,
         }
 	            
 }
-			if(eigen(Sigma)$values[k]<=0)
-			{
-			Sigma <- as.matrix(nearPD(Sigma, corr = TRUE)$mat)
-			warning("Cannot find a feasible correlation matrix for MVN ensuring Sigma for the given margins...")
-			Sigmaord<-contord(marginal, Sigma, support, Spearman)
+		
 
-    }
+if(eigen(Sigma)$values[k]<=0)
+{
+stop("The Sigma matrix is not coherent with the given margins or
+it is impossible to find a feasible correlation matrix for MVN
+ensuring Sigma for the given margins")
+}
     emax <- max(abs(Sigmaord - Sigma0))
     list(SigmaC = Sigma, SigmaO = Sigmaord, Sigma = Sigma0, niter = niter, 
         maxerr = emax)
